Auto Invest Endpoints
======================

Get target asset list (USER_DATA)
---------------------------------
.. autofunction:: binance.spot.Spot.get_target_asset_list

Get target asset ROI data (USER_DATA)
-------------------------------------
.. autofunction:: binance.spot.Spot.get_target_asset_roi_data

Query all source asset and target asset (USER_DATA)
---------------------------------------------------
.. autofunction:: binance.spot.Spot.query_all_source_asset_and_target_asset

Query source asset list (USER_DATA)
-----------------------------------
.. autofunction:: binance.spot.Spot.query_source_asset_list

Change Plan Status (TRADE)
--------------------------
.. autofunction:: binance.spot.Spot.change_plan_status

Get list of plans (USER_DATA)
------------------------------
.. autofunction:: binance.spot.Spot.get_list_of_plans

Query holding details of the plan (USER_DATA)
---------------------------------------------
.. autofunction:: binance.spot.Spot.query_holding_details_of_the_plan

Query subscription transaction history (USER_DATA)
--------------------------------------------------
.. autofunction:: binance.spot.Spot.query_subscription_transaction_history

Query Index Details (USER_DATA)
-------------------------------
.. autofunction:: binance.spot.Spot.query_index_details

Query Index Linked Plan Position Details (USER_DATA)
----------------------------------------------------
.. autofunction:: binance.spot.Spot.query_index_linked_plan_position_details

One Time Transaction (TRADE)
----------------------------
.. autofunction:: binance.spot.Spot.one_time_transaction

Query One-Time Transaction Status (USER_DATA)
---------------------------------------------
.. autofunction:: binance.spot.Spot.query_one_time_transaction_status

Index Linked Plan Redemption (TRADE)
------------------------------------
.. autofunction:: binance.spot.Spot.index_linked_plan_redemption

Index Linked Plan Redemption (USER_DATA)
----------------------------------------
.. autofunction:: binance.spot.Spot.get_index_linked_plan_redemption_history

Index Linked Plan Rebalance Details (USER_DATA)
-----------------------------------------------
.. autofunction:: binance.spot.Spot.index_linked_plan_rebalance_details
